@@ -289,7 +289,7 @@ async def info(bot: IrcBot, args, msg: Message):
             f"{k}: {v} {'MB' if ConfigOptions.quota.name == k else ''}"
             for k, v in Config.get(msg.nick).asdict().items()
         ]
-        + [f"usage: {Folder(msg.nick).size()} MB"],
+        + [f"usage: {round(Folder(msg.nick).size() / 1048576, 2)} MB"],
     )
 
 
@@ -391,15 +391,18 @@ async def send(bot: IrcBot, args, msg):
     nick = args[2]
     now = time()
     await bot.send_raw(f"PING {nick}")
-    notice = bot.wait_for(
-        "notice", from_nick=nick, timeout=5, filter_func=lambda m: "PING" in m["text"]
+    notice = await bot.wait_for(
+        "pong",
+        nick,
+        timeout=5,
+        filter_func=lambda m: nick.strip().casefold() == m["nick"].strip().casefold(),
     )
-    ping = round(now - time(), 4)
     if not notice:
         return f"The nick {nick} is not available or timed out"
 
+    ping = round(- now + time(), 4)
     await bot.send_message(f"Sending {file.name} to {nick}. Ping: {ping}s", msg.nick)
-    await send_file(bot, msg.nick, file)
+    await send_file(bot, nick, file)
 
 
 @utils.arg_command(
@@ -451,9 +454,9 @@ async def imgur(bot: IrcBot, args, msg):
         error_out()
 
     error, file = check_nick_has_file(msg.nick, args[1])
-    size = file.stat().st_size
     if error:
         return error
+    size = file.stat().st_size
     img_exts = ["JPEG", "PNG", "GIF", "APNG", "TIFF"]
     anim_exts = ["MP4", "MPEG", "AVI", "WEBM"]
     ext = file.suffix.replace(".", "").upper()
